==> maxdb-source-7_5_00_38.tgz: V75_00_38/MaxDB_ORG/sys/src/SAPDB/SQLManager/SQLMan_ErrPascalWrapper.cpp <==
/*!***************************************************************************

  module      : SQLMan_ErrPascalWrapper.cpp

  -------------------------------------------------------------------------

  responsible : ElkeZ

  special area: SQL Manager
  description : defines PASCAL interface of SQL manager.

  last changed: 2000-12-06  19:04
  see also    : example.html ...
  first created:2000-03-09  18:21

  -------------------------------------------------------------------------

  copyright:    (c) 2000-2004 SAP AG




    ========== licence begin  GPL
    Copyright (c) 2000-2005 SAP AG

    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
    as published by the Free Software Foundation; either version 2
    of the License, or (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
    ========== licence end




*****************************************************************************/

#include "hgg171.h"
#include "SQLManager/ErrorHandling/SQLManErr_Instance.hpp"

/*----------------------------------------------------------------*/

void g171_baseerrortext (
    tgg00_BasisError                     b_err,
    char*                                text,
    integer                              textsize)
{
    const char *baseText = SQLManErr_Interface::GetInstance().GetBaseErrorText(b_err);
	if (NULL != baseText)
	{
        int msglen = strlen (baseText);
		if (msglen > textsize)
		{
			msglen = textsize;
		}
		memcpy (text, baseText, msglen);
    }
	return;
}

/*----------------------------------------------------------------*/

==> maxdb-source-7_6_00_09.tgz: V76_00_09/MaxDB_ORG/sys/src/SAPDB/SQLManager/SQLMan_ErrPascalWrapper.cpp <==
/*!***************************************************************************

  module      : SQLMan_ErrPascalWrapper.cpp

  -------------------------------------------------------------------------

  responsible : ElkeZ

  special area: SQL Manager
  description : defines PASCAL interface of SQL manager.

  last changed: 2000-12-06  19:04
  see also    : example.html ...
  first created:2000-03-09  18:21

  -------------------------------------------------------------------------

  copyright:    Copyright (c) 2000-2004 SAP AG




    ========== licence begin  GPL
    Copyright (c) 2000-2004 SAP AG

    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
    as published by the Free Software Foundation; either version 2
    of the License, or (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
    ========== licence end



*****************************************************************************/

#include "hgg171.h"
#include "SQLManager/ErrorHandling/SQLManErr_Instance.hpp"
#include "SAPDBCommon/SAPDB_MemCopyMove.hpp"

/*----------------------------------------------------------------*/

void g171_baseerrortext (
    tgg00_BasisError                     b_err,
    char*                                text,
    integer                              textsize)
{
    const char *baseText = SQLManErr_Interface::GetInstance().GetBaseErrorText(b_err);
	if (NULL != baseText)
	{
        int msglen = strlen (baseText);
		if (msglen > textsize)
		{
			msglen = textsize;
		}
		SAPDB_MemCopyNoCheck (text, baseText, msglen);
    }
	return;
}

/*----------------------------------------------------------------*/
